@@ -67,7 +67,7 @@ ExecStop=/bin/kill -INT $MAINPID
 WantedBy=multi-user.target
 """
 
-__version__ = '2.0.3'
+__version__ = '2.0.5'
 __all__ = (
 	'AdvancedHTTPServer',
 	'RegisterPath',
@@ -1002,7 +1002,11 @@ class RequestHandler(http.server.BaseHTTPRequestHandler, object):
 			self.wfile = self._wfile
 		super(RequestHandler, self).send_response(*args, **kwargs)
 		self.headers_active = True
-		if self.headers.get('Connection', None) == 'keep-alive' and self.protocol_version.upper() == 'HTTP/1.1':
+
+		# in the event that the http request is invalid, all attributes may not be defined
+		headers = getattr(self, 'headers', {})
+		protocol_version = getattr(self, 'protocol_version', 'HTTP/1.0').upper()
+		if headers.get('Connection', None) == 'keep-alive' and protocol_version == 'HTTP/1.1':
 			connection = 'keep-alive'
 		else:
 			connection = 'close'
@@ -1235,7 +1239,7 @@ class RequestHandler(http.server.BaseHTTPRequestHandler, object):
 			response['exception_occurred'] = True
 			exc_name = "{0}.{1}".format(error.__class__.__module__, error.__class__.__name__)
 			response['exception'] = dict(name=exc_name, message=getattr(error, 'message', None))
-			self.server.logger.error('error: ' + exc_name + ' occurred while calling RPC method: ' + self.path)
+			self.server.logger.error('error: ' + exc_name + ' occurred while calling rpc method: ' + self.path, exc_info=True)
 
 		try:
 			response = serializer.dumps(response)
